@@ -1,9 +1,6 @@
 package PMLTQ;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::VERSION = '0.8.3';
-}
-
+$PMLTQ::VERSION = '1.0.0';
 # ABSTRACT: Query engine and query language for trees in PML format
 
 
@@ -15,12 +12,12 @@ use File::Spec ();
 use File::ShareDir 'dist_dir';
 
 my $home_dir = File::Spec->catdir(dirname(__FILE__), __PACKAGE__);
+my $local_shared_dir = File::Spec->catdir(dirname(__FILE__), File::Spec->updir, 'share');
 my $shared_dir = eval {	dist_dir(__PACKAGE__) };
 
 # Assume installation
-unless ($shared_dir) {
-	my $updir = File::Spec->updir();
-	$shared_dir = File::Spec->catdir(dirname(__FILE__), $updir, 'share');	
+if (-d $local_shared_dir or !$shared_dir) {
+  $shared_dir = $local_shared_dir;
 }
 
 sub home { $home_dir }
@@ -43,7 +40,11 @@ PMLTQ - Query engine and query language for trees in PML format
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
+
+=for html <a href="https://travis-ci.org/ufal/perl-pmltq"><img src="https://travis-ci.org/ufal/perl-pmltq.svg?branch=master" alt="Build Status"></a>
+<a href="https://coveralls.io/github/ufal/perl-pmltq?branch=master"><img src="https://coveralls.io/repos/ufal/perl-pmltq/badge.svg?branch=master&amp;service=github" alt="Coverage Status"></a>
+<a href="https://badge.fury.io/pl/PMLTQ"><img src="https://badge.fury.io/pl/PMLTQ.svg" alt="CPAN version"></a>
 
 =head1 DESCRIPTION
 
@@ -67,11 +68,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
