@@ -1,9 +1,6 @@
 package PMLTQ::Common;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::Common::VERSION = '0.8.3';
-}
-
+$PMLTQ::Common::VERSION = '1.0.0';
 # ABSTRACT: Helper functions mainly for PML manipulations
 
 use 5.006;
@@ -151,9 +148,9 @@ my %type = (
 );
 
 sub reversed_relation {
-  my ($name,$node_type)=@_;
+  my ($schema_name,$node_type,$name)=@_;
   if ($name=~s{^implementation:}{}) {
-    return PMLTQ::Relation->reversed_relation($node_type,$name);
+    return PMLTQ::Relation->reversed_relation($schema_name,$node_type,$name);
   }
   return $reversed_relations{$name};
 }
@@ -1198,7 +1195,7 @@ PMLTQ::Common - Helper functions mainly for PML manipulations
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 AUTHORS
 
@@ -1216,11 +1213,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
