@@ -1,42 +1,47 @@
 package PMLTQ::Loader;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::Loader::VERSION = '0.8.3';
-}
-
+$PMLTQ::Loader::VERSION = '1.0.0';
 # ABSTRACT: Module loader for L<PMLTQ::Relation|PMLTQ::Relation>s inspired by L<Mojo::Loader>
 
 
-use strict;
-use warnings;
+use PMLTQ::Base -strict;
+
+use Exporter 'import';
 use File::Basename 'fileparse';
 use File::Spec;
 
+our @EXPORT_OK
+  = qw(find_modules load_class);
+
 sub class_to_path { join '.', join('/', split /::|'/, shift), 'pm' }
 
-sub load {
-  my ($class, $module) = @_;
- 
+sub load_class {
+  my ($class) = @_;
+
   # Check module name
-  return 1 if !$module || $module !~ /^\w(?:[\w:']*\w)?$/;
- 
-  # Load
-  return undef if $module->can('new') || eval "require $module; 1";
- 
+  return if !$class || $class !~ /^\w(?:[\w:']*\w)?$/;
+
+  # Loaded
+  return 1 if $class->can('new') || eval {
+    my $file = class_to_path($class);
+    require $file;
+    1;
+  };
+
   # Exists
-  return 1 if $@ =~ /^Can't locate \Q@{[class_to_path $module]}\E in \@INC/;
- 
+  return if $@ =~ /^Can't locate \Q@{[class_to_path $class]}\E in \@INC/;
+
   # Real error
   die $@;
 }
- 
-sub search {
-  my ($class, $ns) = @_;
- 
+
+sub find_modules {
+  my ($ns) = @_;
+
   my %modules;
   for my $directory (@INC) {
     next unless -d (my $path = File::Spec->catdir($directory, split(/::|'/, $ns)));
- 
+
     # List "*.pm" files in directory
     opendir(my $dir, $path);
     for my $file (grep /\.pm$/, readdir $dir) {
@@ -44,7 +49,7 @@ sub search {
       $modules{"${ns}::" . fileparse $file, qr/\.pm/}++;
     }
   }
- 
+
   return keys %modules;
 }
 
@@ -62,14 +67,14 @@ PMLTQ::Loader - Module loader for L<PMLTQ::Relation|PMLTQ::Relation>s inspired b
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 SYNOPSIS
 
-  use PMLTQ::Loader;
-  for my $module (PMLTQ::Loader->search('PMLTQ::Relation')) {
+  use PMLTQ::Loader qw/find_modules load_class/;
+  for my $module (find_modules('PMLTQ::Relation')) {
     print "Loading module: '$module'\n";
-    PMLTQ::Loader->load($module);
+    load_class($module);
   }
 
 =head1 DESCRIPTION
@@ -93,11 +98,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
