@@ -1,9 +1,6 @@
 package PMLTQ::NG2PMLTQ;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::NG2PMLTQ::VERSION = '0.8.3';
-}
-
+$PMLTQ::NG2PMLTQ::VERSION = '1.0.0';
 # ABSTRACT: [DEPRECATED] Conversion functions from NetGraph to PML-TQ
 
 
@@ -334,7 +331,7 @@ PMLTQ::NG2PMLTQ - [DEPRECATED] Conversion functions from NetGraph to PML-TQ
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -370,11 +367,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
