@@ -1,9 +1,6 @@
 package PMLTQ::ParserError;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::ParserError::VERSION = '0.8.3';
-}
-
+$PMLTQ::ParserError::VERSION = '1.0.0';
 # ABSTRACT: Wrapper for parsing error
 
 1; # End of PMLTQ::ParserError
@@ -20,7 +17,7 @@ PMLTQ::ParserError - Wrapper for parsing error
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 AUTHORS
 
@@ -38,11 +35,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
