@@ -1,9 +1,6 @@
 package PMLTQ::Planner;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::Planner::VERSION = '0.8.3';
-}
-
+$PMLTQ::Planner::VERSION = '1.0.0';
 # ABSTRACT: Optimalizing search trees for BtredEvaluator
 
 
@@ -63,11 +60,11 @@ sub name_all_query_nodes {
   return \%name2node;
 }
 sub weight {
-  my ($rel,$node_type)=@_;
+  my ($schema_name,$node_type,$rel)=@_;
   my $name = $rel->name;
   my $w;
   if ($name eq 'user-defined') {
-    $w = PMLTQ::Relation->iterator_weight($node_type,$name) || $weight{'user-defined:'.$name};
+    $w = PMLTQ::Relation->iterator_weight($schema_name,$node_type,$name) || $weight{'user-defined:'.$name};
   } else {
     $w = $weight{$name};
   }
@@ -76,13 +73,13 @@ sub weight {
   return 5;
 }
 sub reversed_rel {
-  my ($ref,$start_type)=@_;
+  my ($schema_name,$start_type,$ref)=@_;
   my ($rel)=SeqV($ref->{relation});
   my $name = $rel->name;
   if ($name eq 'user-defined') {
     $name=$rel->value->{category}.':'.$rel->value->{label};
   }
-  my $rname = PMLTQ::Common::reversed_relation($name,$start_type);
+  my $rname = PMLTQ::Common::reversed_relation($schema_name,$start_type,$name);
   if (defined $rname) {
     my $relv = $rel->value;
     my $revv = Treex::PML::CloneValue($relv);
@@ -108,9 +105,9 @@ sub reversed_rel {
 }
 
 sub plan {
-  my ($query_nodes,$query_tree,$query_root)=@_;
-  die 'usage: plan(\@nodes,$query_tree,$query_node?)' unless
-    ref($query_nodes) eq 'ARRAY' and $query_tree;
+  my ($type_mapper,$query_nodes,$query_tree,$query_root)=@_;
+  die 'usage: plan($type_mapper,\@nodes,$query_tree,$query_node?)' unless
+    $type_mapper and ref($query_nodes) eq 'ARRAY' and $query_tree;
   my %node2pos = map { $query_nodes->[$_] => $_ } 0..$#$query_nodes;
   my %name2pos = map {
     my $name = $query_nodes->[$_]->{name};
@@ -195,11 +192,11 @@ sub plan {
 	  ref=>$ref,
 	  real_start=>$edge_data->[0],
 	  real_end=>$edge_data->[1],
-	  weight=>weight($rel,$sn->{'node-type'}),
+	  weight=>weight($type_mapper->get_schema_name_for($sn->{'node-type'}),$sn->{'node-type'},$rel),
 	} unless defined($root_pos) and $t==$root_pos;
       }
       unless ($no_reverse or (defined($root_pos) and $s==$root_pos)) {
-	my $reversed = reversed_rel($ref,$tn->{'node-type'});
+	my $reversed = reversed_rel($type_mapper->get_schema_name_for($tn->{'node-type'}),$tn->{'node-type'},$ref);
 	if (defined $reversed) {
 	  push @edges,{
 	  from => $t,
@@ -208,7 +205,7 @@ sub plan {
 	  reverse_of_ref => $ref,
 	  real_start=>$edge_data->[1],
 	  real_end=>$edge_data->[0],
-	  weight => weight($reversed,$tn->{'node-type'}),
+	  weight => weight($type_mapper->get_schema_name_for($tn->{'node-type'}),$tn->{'node-type'},$reversed),
 	};
 	}
       }
@@ -293,7 +290,7 @@ PMLTQ::Planner - Optimalizing search trees for BtredEvaluator
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 DESCRIPTION
 
@@ -317,11 +314,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
