@@ -1,9 +1,6 @@
 package PMLTQ::Relation::DepthFirstRangeIterator;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::Relation::DepthFirstRangeIterator::VERSION = '0.8.3';
-}
-
+$PMLTQ::Relation::DepthFirstRangeIterator::VERSION = '1.0.0';
 # ABSTRACT: Iterates tree using depth first search in given boundaries
 
 
@@ -144,7 +141,7 @@ PMLTQ::Relation::DepthFirstRangeIterator - Iterates tree using depth first searc
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -171,11 +168,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
