@@ -1,9 +1,6 @@
 package PMLTQ::Relation::MemberIterator;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::Relation::MemberIterator::VERSION = '0.8.3';
-}
-
+$PMLTQ::Relation::MemberIterator::VERSION = '1.0.0';
 # ABSTRACT: Iterates over member nodes of given list
 
 use 5.006;
@@ -50,7 +47,7 @@ PMLTQ::Relation::MemberIterator - Iterates over member nodes of given list
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 AUTHORS
 
@@ -68,11 +65,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
