@@ -1,9 +1,6 @@
 package PMLTQ::Relation::PMLREFIterator;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::Relation::PMLREFIterator::VERSION = '0.8.3';
-}
-
+$PMLTQ::Relation::PMLREFIterator::VERSION = '1.0.0';
 # ABSTRACT: Iterates over PML reference
 
 use 5.006;
@@ -52,7 +49,7 @@ sub get_node_list  {
       my $n = PML::GetNodeByID($id,$fsfile);
       $n ? [$n, $fsfile] : ()
     }
-  } Treex::PML::Instance::get_all($node,$self->[ATTR])];
+  } grep { defined } Treex::PML::Instance::get_all($node,$self->[ATTR])];
 }
 
 1; # End of PMLTQ::Relation::PMLREFIterator
@@ -69,7 +66,7 @@ PMLTQ::Relation::PMLREFIterator - Iterates over PML reference
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 AUTHORS
 
@@ -87,11 +84,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
