@@ -1,9 +1,6 @@
 package PMLTQ::TypeMapper;
 our $AUTHORITY = 'cpan:MICHALS';
-{
-  $PMLTQ::TypeMapper::VERSION = '0.8.3';
-}
-
+$PMLTQ::TypeMapper::VERSION = '1.0.0';
 # ABSTRACT: Helper methods for PML::Schema, relations and PML::Node types
 
 use 5.006;
@@ -13,8 +10,11 @@ use Treex::PML::Schema;
 use Carp;
 
 use PMLTQ::Common (qw(uniq first));
+use PMLTQ::Relation;
 use UNIVERSAL::DOES;
 
+PMLTQ::Relation->load();
+
 BEGIN { # TredMacro should work in TrEd 2.0
     eval {
         require TrEd::MacroAPI::Default;
@@ -61,6 +61,13 @@ sub get_schema_for_type {
   return $decl && $decl->get_schema;
 }
 
+sub get_schema_name_for {
+  my ($self,$type)=@_;
+
+  my $schema = $self->get_schema_for_type($type);
+  return $schema ? $schema->get_root_name : undef;
+}
+
 sub _get_fsfile {
   my ($self)=@_;
   my $fsfile = $self->{fsfile};
@@ -103,7 +110,7 @@ sub get_schemas {
 
 sub get_schema_names {
   my ($self)=@_;
-  return [uniq(map { $_->get_root_name }  $self->get_schemas)];
+  return [uniq(grep { defined } map { $_->get_root_name }  $self->get_schemas)];
 }
 
 sub get_type_decl_for_query_node {
@@ -213,7 +220,8 @@ sub get_user_defined_relations {
   my ($self,$qnode_or_type)=@_;
   if ($qnode_or_type) {
     my $type = ref($qnode_or_type) ? PMLTQ::Common::GetQueryNodeType($qnode_or_type,$self) : $qnode_or_type;
-    return PMLTQ::Relation->relations_for_node_type($type);
+    my $schema_name = $self->get_schema_name_for($type);
+    return $schema_name ? PMLTQ::Relation->relations_for_node_type($schema_name, $type) : []; # Ignore if it doesn't have schema_name
   }
   return [
     map @{$self->get_user_defined_relations($_)}, grep $_, @{$self->get_node_types}
@@ -268,7 +276,7 @@ PMLTQ::TypeMapper - Helper methods for PML::Schema, relations and PML::Node type
 
 =head1 VERSION
 
-version 0.8.3
+version 1.0.0
 
 =head1 AUTHORS
 
@@ -286,11 +294,15 @@ Jan Štěpánek <stepanek@ufal.mff.cuni.cz>
 
 Michal Sedlák <sedlak@ufal.mff.cuni.cz>
 
+=item *
+
+Matyáš Kopp <matyas.kopp@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
+This software is copyright (c) 2015 by Institute of Formal and Applied Linguistics (http://ufal.mff.cuni.cz).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
